summaryrefslogtreecommitdiffstats
path: root/kwin/clients/keramik/config/config.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kwin/clients/keramik/config/config.cpp')
-rw-r--r--kwin/clients/keramik/config/config.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/kwin/clients/keramik/config/config.cpp b/kwin/clients/keramik/config/config.cpp
index c548ca184..b4b6ced9b 100644
--- a/kwin/clients/keramik/config/config.cpp
+++ b/kwin/clients/keramik/config/config.cpp
@@ -26,14 +26,14 @@
#include <kglobal.h>
#include <klocale.h>
-#include <qcheckbox.h>
+#include <tqcheckbox.h>
#include "config.h"
#include "config.moc"
extern "C"
{
- KDE_EXPORT QObject* allocate_config( KConfig* conf, QWidget* parent )
+ KDE_EXPORT TQObject* allocate_config( KConfig* conf, TQWidget* parent )
{
return ( new KeramikConfig( conf, parent ) );
}
@@ -44,21 +44,21 @@ extern "C"
* 'conf' is a pointer to the kwindecoration modules open kwin config,
* and is by default set to the "Style" group.
*
* 'parent' is the parent of the QObject, which is a VBox inside the
* Configure tab in kwindecoration
*/
-KeramikConfig::KeramikConfig( KConfig* conf, QWidget* parent )
- : QObject( parent )
+KeramikConfig::KeramikConfig( KConfig* conf, TQWidget* parent )
+ : TQObject( parent )
{
KGlobal::locale()->insertCatalogue("kwin_clients");
c = new KConfig( "kwinkeramikrc" );
ui = new KeramikConfigUI( parent );
- connect( ui->showAppIcons, SIGNAL(clicked()), SIGNAL(changed()) );
- connect( ui->smallCaptions, SIGNAL(clicked()), SIGNAL(changed()) );
- connect( ui->largeGrabBars, SIGNAL(clicked()), SIGNAL(changed()) );
- connect( ui->useShadowedText, SIGNAL(clicked()), SIGNAL(changed()) );
+ connect( ui->showAppIcons, TQT_SIGNAL(clicked()), TQT_SIGNAL(changed()) );
+ connect( ui->smallCaptions, TQT_SIGNAL(clicked()), TQT_SIGNAL(changed()) );
+ connect( ui->largeGrabBars, TQT_SIGNAL(clicked()), TQT_SIGNAL(changed()) );
+ connect( ui->useShadowedText, TQT_SIGNAL(clicked()), TQT_SIGNAL(changed()) );
load( conf );
ui->show();
@@ -44,21 +44,21 @@ extern "C"
* and is by default set to the "Style" group.
*
- * 'parent' is the parent of the QObject, which is a VBox inside the
+ * 'parent' is the parent of the TQObject, which is a VBox inside the
* Configure tab in kwindecoration
*/